ALEPHS
======

Pakistan's emergency services.


Details
-------

Catalogue of emergency services in Pakistan for a consolidated lookup.


Package Usage
-------------

from alephs import alephs

\# Get version

alephs.get_version()

\# get list of institutions

insts = alephs.get_institutes()
